@@ -1,6 +1,7 @@
 
 /*
- * database.c
+ * $Id: database.c,v 1.9 2001/06/11 08:40:38 jheinonen Exp $
+ *
  * by JH <jheinonen@bigfoot.com>
  *
  * Copyright (C) Jaakko Heinonen
@@ -11,7 +12,6 @@
 #include <string.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include "abook_curses.h"
 #include "abook.h"
 #include "database.h"
 #include "list.h"
@@ -139,9 +139,10 @@ load_database(char *filename)
 }
 
 int
-write_database(FILE *out)
+write_database(FILE *out, struct db_enumerator e)
 {
-	int i,j;
+	int j;
+	int i = 0;
 
 	fprintf(out, "# abook addressbook file\n\n");
 	fprintf(out, "[format]\n");
@@ -149,15 +150,18 @@ write_database(FILE *out)
 	fprintf(out, "version=" VERSION "\n");
 	fprintf(out, "\n\n");
 
-	for( i = 0; i < items; i++ ) {
+	db_enumerate_items(e) {
 		fprintf(out, "[%d]\n", i);
 		for(j=0; j<ITEM_FIELDS; j++) {
-			if( database[i][j] != NULL )
-				if( *database[i][j] )
-					fprintf(out, "%s=%s\n",
-						abook_fields[j].key, database[i][j]);
+			if( database[e.item][j] != NULL &&
+					*database[e.item][j] )
+				fprintf(out, "%s=%s\n",
+					abook_fields[j].key,
+					database[e.item][j]
+					);
 		}
 		fputc('\n', out);
+		i++;
 	}
 
 	return 0;
@@ -167,18 +171,19 @@ int
 save_database()
 {
 	FILE *out;
+	struct db_enumerator e = init_db_enumerator(ENUM_ALL);
 
 	if( (out = abook_fopen(datafile, "w")) == NULL )
 		return -1;
 
-	if( items < 1 ) {
+	if( list_is_empty() ) {
 		fclose(out);
 		unlink(datafile);
 		return 1;
 	}
 
 	
-	write_database(out);
+	write_database(out, e);
 	
 	fclose(out);
 	
@@ -277,23 +282,13 @@ add_item2database(list_item item)
 }
 
 void
-remove_items()
+remove_selected_items()
 {
 	int i, j;
 
-	if( items < 1 || curitem < 0 )
+	if( list_is_empty() )
 		return;
 
-	statusline_addstr("Remove selected item(s) (Y/n)");
-	switch( getch() ) {
-		case '\r':
-		case 'y':
-		case 'Y': break;
-		default:
-			  clear_statusline();
-			  return;
-	}
-
 	if( ! selected_items() )
 		selected[ curitem ] = 1;
 	
@@ -315,8 +310,6 @@ remove_items()
 	adjust_list_capacity();
 
 	select_none();
-	clear_statusline();	
-	refresh_list();
 }
 
 char *
@@ -392,111 +385,90 @@ sort_surname()
 	refresh_screen();
 }
 
-void
-clear_database()
-{
-
-	statusline_addstr("Clear WHOLE database (y/N)");
-	switch( getch() ) {
-		case 'y':
-		case 'Y': break;
-		default:
-			clear_statusline();
-			return;
-	}
-
-	close_database();
-
-	refresh_screen();
-}
-
-void
-find(int next)
+int
+find_item(char *str, int start, int search_fields[])
 {
 	int i;
-	static char findstr[81];
-	char tmp[81];
+	char *findstr = NULL;
+	char *tmp = NULL;
+	int ret = -1; /* not found */
+	struct db_enumerator e = init_db_enumerator(ENUM_ALL);
 
+	if(list_is_empty() || !is_valid_item(start))
+		return -2; /* error */
+
+	findstr = strdup(str);
+	findstr = strupper(findstr);
+
+	e.item = start - 1; /* must be "real start" - 1 */
+	db_enumerate_items(e) {
+		for( i = 0; search_fields[i] >= 0; i++ ) {
+			tmp = safe_strdup(database[e.item][search_fields[i]]);
+			if( tmp && strstr(strupper(tmp), findstr) ) {
+				ret = e.item;
+				goto out;
+			}
+			my_free(tmp);
+		}
+	}
+
+out:
+	free(findstr);
+	free(tmp);
+	return ret;
+}
+
+
+int
+is_selected(int item)
+{
+	return selected[item];
+}
+
+int
+is_valid_item(int item)
+{
+	return item <= LAST_ITEM && item >= 0;
+}
+
+int
+real_db_enumerate_items(struct db_enumerator e)
+{
+	int item = max(0, e.item + 1);
+	int i;
+	
+	switch(e.mode) {
 #ifdef DEBUG
-	fprintf(stderr, "find(): findstr = |%s|\n", findstr);
+		case ENUM_ALL:
+			break;
 #endif
-	
-	if(next) {
-		if( !*findstr )
-			return;
-	} else {
-		clear_statusline();
-		statusline_addstr("/");
-		statusline_getnstr(findstr, 67, 0);
-		strupper(findstr);
-		clear_statusline();
-	}
-
-	if(items < 1)
-		return;
-
-	for( i = (curitem < LAST_ITEM) && next ? curitem+1 : curitem;
-			i < items; i++ ) {
-		strcpy(tmp, database[i][NAME]);
-		if( strstr(strupper(tmp), findstr) != NULL ) {
-			curitem = i;
-			refresh_list();
+		case ENUM_SELECTED:
+			for(i = item; i < items; i++) {
+				if(is_selected(i)) {
+					item = i;
+					goto out;
+				}
+			}
+			return -1;
+#ifdef DEBUG
+		default:
+			fprintf(stderr, "real_db_enumerate_items() "
+					"BUG: unknown db_enumerator mode: %d\n",
+					e.mode);
 			break;
-		}
+#endif
 	}
+out:
+	return (item > LAST_ITEM || item < 0) ? -1 : item;
 }
 
-
-void
-print_number_of_items()
+struct db_enumerator
+init_db_enumerator(int mode)
 {
-	char *str =
-		mkstr("     |%3d/%3d", selected_items(), items);
+	struct db_enumerator new;
 
-	mvaddstr(0, COLS-strlen(str), str);
+	new.item = -1; /* important - means "start from beginning" */
+	new.mode = mode;
 
-	free(str);
+	return new;
 }
-
-void
-read_database()
-{
-	if(items > 0) {
-		statusline_addstr("Your current data will be lost - Press 'y' to continue");
-		switch( getch() ) {
-			case 'y':
-			case 'Y': break;
-			default: clear_statusline();
-				 return;
-		}
-		clear_statusline();
-	}
-
-	load_database(datafile);
-	refresh_list();
-}
-
-
-void
-print_database()
-{
-	FILE *handle;
-	char *command = options_get_str("print_command");
-
-	statusline_addstr("Print addressbook? (y/N)");
-	switch( getch() ) {
-		case 'y':
-		case 'Y':
-			break;
-		default: clear_statusline(); return;
-	}
-	clear_statusline();
-
-	if( ! *command || (handle = popen(command, "w")) == NULL)
-		return;
-
-	fexport("text", handle);
-	
-	pclose(handle);
-}
-
