@@ -39,7 +39,7 @@ static char *mainhelp[] = {
 "	Z		move current item down\n",
 "\n",
 "	m		send mail with mutt\n",
-"	u		view URL with lynx\n",
+"	u		view URL with www browser\n",
 NULL
 
 };
@@ -51,10 +51,16 @@ static char *editorhelp[] = {
 "\n",
 "	1 - 5			edit fields\n",
 "\n",
+"	k or <			previous item\n",
+"	j or >			next item\n",
+"\n",
 "	r			roll e-mail addresses\n",
 "\n",
 "	u			undo\n",
 "\n",
+"	m			send mail with mutt\n",
+"	v			view url with WWW browser\n",
+"\n",
 NULL
 
 };
