@@ -1,6 +1,7 @@
 
 /*
- * list.c
+ * $Id: list.c,v 1.6 2001/06/12 14:01:18 jheinonen Exp $
+ *
  * by JH <jheinonen@bigfoot.com>
  *
  * Copyright (C) Jaakko Heinonen
@@ -8,8 +9,8 @@
 
 #include <stdio.h>
 #include <string.h>
-#include "abook_curses.h"
 #include "abook.h"
+#include "ui.h"
 #include "database.h"
 #include "edit.h"
 #include "list.h"
@@ -47,7 +48,7 @@ refresh_list()
 	
 	werase(list);
 
-	print_number_of_items();
+	ui_print_number_of_items();
 	
 	if( items < 1 ) {
 		refresh();
@@ -86,7 +87,7 @@ print_list_line(int i, int line)
 	char tmp[MAX_EMAILSTR_LEN];
 	int extra_column = options_get_int("extra_column");
 	int real_emaillen = (extra_column > 2 && extra_column < ITEM_FIELDS) ?
-		EMAILLEN : EMAILPOS - COLS;
+		EMAILLEN : COLS - EMAILPOS;
 
 	scrollok(list, FALSE);
 
@@ -269,13 +270,13 @@ highlight_line(WINDOW *win, int line)
 int
 selected_items()
 {
-	int i, a=0;
+	int i, n = 0;
 
 	for(i = 0; i < items; i++)
 		if(selected[i])
-			a++;
+			n++;
 
-	return a;
+	return n;
 }
 
 void
@@ -290,3 +291,16 @@ invert_selection()
 		selected[i] = !selected[i];
 }
 
+inline int
+list_current_item()
+{
+	return curitem;
+}
+
+inline int
+list_is_empty()
+{
+	return items < 1;
+}
+
+	
