@@ -1,6 +1,7 @@
 
 /*
- * misc.c
+ * $Id: misc.c,v 1.3 2001/06/11 12:51:54 jheinonen Exp $
+ *
  * by JH <jheinonen@bigfoot.com>
  *
  * Copyright (C) Jaakko Heinonen
@@ -122,10 +123,13 @@ mkstr (const char *format, ... )
 				format, ap);
 		MY_VA_END;
 
-		if (n > -1)
+		if (n > -1 && n < size)
 			return buffer;
 
-		size *= 2;
+		if (n > -1)
+			size = n + 1;
+		else
+			size *= 2;
 		
 		buffer =
 #ifdef ABOOK_SRC
