@@ -4,6 +4,7 @@
 char		*revstr(char *str);
 char		*strupper(char *str);
 char		*strlower(char *str);
+char		*strtrim(char *);
 
 char		*mkstr (const char *format, ... );
 char		*strconcat (const char *str, ...);
@@ -12,6 +13,8 @@ int		safe_strcmp(const char *s1, const char * s2);
 
 char		*my_getcwd();
 
+char		*getaline(FILE *f);
+
 #ifdef HAVE_CONFIG_H
 #	include "config.h"
 #endif
