@@ -1,6 +1,7 @@
 
 /*
- * options.c
+ * $Id: options.c,v 1.6 2001/06/06 16:27:56 jheinonen Exp $
+ *
  * by JH <jheinonen@bigfoot.com>
  *
  * Copyright (C) Jaakko Heinonen
@@ -9,7 +10,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <unistd.h>
 #include "abook_curses.h"
 #include "abook.h"
 #include "options.h"
@@ -88,15 +88,6 @@ close_config()
 	conff_free_nodes(abook_config);
 }
 
-void
-edit_options()
-{
-	/*
-	 * not yet implemented
-	 * edit your ~/.abook.conf manually
-	 */
-}
-
 static int
 rcfile_exist()
 {
@@ -161,4 +152,6 @@ default_options()
 	options_add_key("www_command", "lynx");
 
 	options_add_key("address_style", "eu");
+
+	options_add_key("use_ascii_only", "false");
 }
